<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class CrmModalidadeDePagamentoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getModalityPaymentFactory()
    {
        $sql = "SELECT
                    MOD.CDMODPGTO,
                    MOD.DSMODPGTO,
                    MOD.CDFORMPGTO,
                    DECODE(MOD.IDTPFORPGTOMOD, '', 'A', MOD.IDTPFORPGTOMOD) AS IDTPFORPGTOMOD,
                    MOD.NRDIAPGFIXMOD,
                    MOD.NRPARCPGTOMOD,
                    MOD.IDUTDIAPAGMOD,
                    MOD.VRFATAJUPARC,
                    MOD.CDTIPORECE,
                    MOD.VRPEDESMODPG,
                    MOD.DTULTATUMPGT,
                    MOD.IDLANCPEDMOD,
                    MOD.VRFATORCOMISSAO,
                    MOD.NRORG,
                    MOD.DTINCLUSAO,
                    MOD.DTULTATU,
                    MOD.NRORGINCLUSAO,
                    MOD.CDOPERINCLUSAO,
                    MOD.NRORGULTATU,
                    MOD.CDOPERULTATU,
                    MOD.IDATIVO,
                    FORM.NMFORMPGTO,
                    TIPO.NMTIPORECE
                FROM
                    MODPGTO  MOD
                    LEFT JOIN FORMPGTO FORM ON MOD.CDFORMPGTO = FORM.CDFORMPGTO
                                            AND MOD.NRORG = FORM.NRORG
                    LEFT JOIN TIPORECE TIPO ON MOD.CDTIPORECE = TIPO.CDTIPORECE
                                            AND MOD.NRORG = TIPO.NRORG
    ";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function formOfPaymentFactory()
    {
        $sql = "SELECT CDFORMPGTO, NMFORMPGTO from FORMPGTO ORDER BY NMFORMPGTO ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function typeOfPaymentFactory()
    {
        $sql = "SELECT * FROM TIPORECE ORDER BY NMTIPORECE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertNewModalityPaymentFactory($params)
    {
        $sql = "INSERT INTO MODPGTO (
            CDMODPGTO,
            IDATIVO,
            DSMODPGTO,
            CDFORMPGTO,
            IDTPFORPGTOMOD,
            NRDIAPGFIXMOD,
            NRPARCPGTOMOD,
            IDUTDIAPAGMOD,
            VRFATAJUPARC,
            CDTIPORECE,
            VRPEDESMODPG,
            DTULTATUMPGT,
            IDLANCPEDMOD,
            VRFATORCOMISSAO,
            NRORG,
            DTINCLUSAO,
            DTULTATU,
            NRORGINCLUSAO,
            NRORGULTATU,
            CDOPERINCLUSAO,
            CDOPERULTATU,
            VRPERCERENT,
            VRFATORRENT
        ) VALUES (
            :CDMODPGTO,
            :IDATIVO,
            :DSMODPGTO,
            :CDFORMPGTO,
            :IDTPFORPGTOMOD,
            :NRDIAPGFIXMOD,
            :NRPARCPGTOMOD,
            :IDUTDIAPAGMOD,
            :VRFATAJUPARC,
            :CDTIPORECE,
            :VRPEDESMODPG,
            SYSDATE,
            :IDLANCPEDMOD,
            :VRFATORCOMISSAO,
            :NRORG,
            SYSDATE,
            SYSDATE,
            :NRORGINCLUSAO,
            :CDOPERINCLUSAO,
            :NRORGULTATU,
            :CDOPERULTATU,
            NULL,
            NULL
        )
        ";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateModalityPaymentFactory($params)
    {
        $sql = "UPDATE MODPGTO
        SET
            CDFORMPGTO = :CDFORMPGTO,
            IDATIVO = :IDATIVO,
            DSMODPGTO = :DSMODPGTO,
            IDTPFORPGTOMOD = :IDTPFORPGTOMOD,
            NRDIAPGFIXMOD = :NRDIAPGFIXMOD,
            NRPARCPGTOMOD = :NRPARCPGTOMOD,
            IDUTDIAPAGMOD = :IDUTDIAPAGMOD,
            VRFATAJUPARC = :VRFATAJUPARC,
            CDTIPORECE = :CDTIPORECE,
            VRPEDESMODPG = :VRPEDESMODPG,
            DTULTATUMPGT = SYSDATE,
            IDLANCPEDMOD = :IDLANCPEDMOD,
            VRFATORCOMISSAO = :VRFATORCOMISSAO,
            NRORG = :NRORG,
            DTULTATU = SYSDATE,
            NRORGINCLUSAO = :NRORGINCLUSAO,
            CDOPERINCLUSAO = :CDOPERINCLUSAO,
            NRORGULTATU = :NRORGULTATU,
            CDOPERULTATU = :CDOPERULTATU,
            VRPERCERENT = NULL,
            VRFATORRENT = NULL
        WHERE
            CDMODPGTO = :CDMODPGTO";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteModalityPaymentFactory($params)
    {
        $sql = "DELETE
                FROM MODPGTO
                WHERE CDMODPGTO IN (" . $params . ")";

        $this->connection->executeStatement($sql);
    }

    public function findRelationshipFactory($params)
    {

        $sql = "SELECT COUNT (CDMODPGTO) AS CDMODPGTO  FROM CRM_TIPOREVENDA 
                WHERE CDMODPGTO = :CDMODPGTO";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}